@@ -83,7 +83,7 @@ class FTSTest(BaseTest):
             self.ae(q, expected_tokens)
 
         self.ae(
-            tokenize("Some wörds"),
+            tokenize('Some wörds'),
             [t('some', 0, 4), t('wörds', 5, 11), t('words', 5, 11, 1)]
         )
         self.ae(
@@ -91,20 +91,20 @@ class FTSTest(BaseTest):
             [t("don't", 0, 5), t('bug', 7, 10)]
         )
         self.ae(
-            tokenize("a,b. c"),
-            [t("a", 0, 1), t('b', 2, 3), t('c', 5, 6)]
+            tokenize('a,b. c'),
+            [t('a', 0, 1), t('b', 2, 3), t('c', 5, 6)]
         )
         self.ae(
-            tokenize("a*b+c"),
-            [t("a", 0, 1), t('b', 2, 3), t('c', 4, 5)]
+            tokenize('a*b+c'),
+            [t('a', 0, 1), t('b', 2, 3), t('c', 4, 5)]
         )
         self.ae(
-            tokenize("a(b[{^c"),
-            [t("a", 0, 1), t('b', 2, 3), t('c', 6, 7)]
+            tokenize('a(b[{^c'),
+            [t('a', 0, 1), t('b', 2, 3), t('c', 6, 7)]
         )
         self.ae(
-            tokenize("a😀smile"),
-            [t("a", 0, 1), t('😀', 1, 5), t('smile', 5, 10)]
+            tokenize('a😀smile'),
+            [t('a', 0, 1), t('😀', 1, 5), t('smile', 5, 10)]
         )
 
         tt("你don't叫mess", '你', "don't", '叫', 'mess')
@@ -125,14 +125,14 @@ class FTSTest(BaseTest):
         conn = TestConn()
         conn.insert_text('two words, and a period. With another.')
         conn.insert_text('and another re-init')
-        self.ae(conn.search("another"), [('and >another< re-init',), ('…With >another<.',)])
-        self.ae(conn.search("period"), [('…a >period<. With another.',)])
+        self.ae(conn.search('another'), [('and >another< re-init',), ('…With >another<.',)])
+        self.ae(conn.search('period'), [('…a >period<. With another.',)])
         self.ae(conn.term_row_counts(), {'a': 1, 're': 1, 'init': 1, 'and': 2, 'another': 2, 'period': 1, 'two': 1, 'with': 1, 'words': 1})
         conn = TestConn()
         conn.insert_text('coộl')
         self.ae(conn.term_row_counts(), {'cool': 1, 'coộl': 1})
-        self.ae(conn.search("cool"), [('>coộl<',)])
-        self.ae(conn.search("coộl"), [('>coộl<',)])
+        self.ae(conn.search('cool'), [('>coộl<',)])
+        self.ae(conn.search('coộl'), [('>coộl<',)])
         conn = TestConn(remove_diacritics=False)
         conn.insert_text('coộl')
         self.ae(conn.term_row_counts(), {'coộl': 1})
@@ -140,13 +140,13 @@ class FTSTest(BaseTest):
         conn = TestConn()
         conn.insert_text("你don't叫mess")
         self.ae(conn.term_row_counts(), {"don't": 1, 'mess': 1, '你': 1, '叫': 1})
-        self.ae(conn.search("mess"), [("你don't叫>mess<",)])
+        self.ae(conn.search('mess'), [("你don't叫>mess<",)])
         self.ae(conn.search('''"don't"'''), [("你>don't<叫mess",)])
-        self.ae(conn.search("你"), [(">你<don't叫mess",)])
+        self.ae(conn.search('你'), [(">你<don't叫mess",)])
         import apsw
         if apsw.sqlitelibversion() not in ('3.44.0', '3.44.1', '3.44.2'):
             # see https://www.sqlite.org/forum/forumpost/d16aeb397d
-            self.ae(conn.search("叫"), [("你don't>叫<mess",)])
+            self.ae(conn.search('叫'), [("你don't>叫<mess",)])
     # }}}
 
     def test_fts_stemming(self):  # {{{
@@ -162,10 +162,10 @@ class FTSTest(BaseTest):
         conn = TestConn(stem_words=True)
         conn.insert_text('a simplistic connection')
         self.ae(conn.term_row_counts(), {'a': 1, 'connect': 1, 'simplist': 1})
-        self.ae(conn.search("connection"), [('a simplistic >connection<',),])
-        self.ae(conn.search("connect"), [('a simplistic >connection<',),])
-        self.ae(conn.search("simplistic connect"), [('a >simplistic< >connection<',),])
-        self.ae(conn.search("simplist"), [('a >simplistic< connection',),])
+        self.ae(conn.search('connection'), [('a simplistic >connection<',),])
+        self.ae(conn.search('connect'), [('a simplistic >connection<',),])
+        self.ae(conn.search('simplistic connect'), [('a >simplistic< >connection<',),])
+        self.ae(conn.search('simplist'), [('a >simplistic< connection',),])
 
     # }}}
 
