@@ -245,7 +245,7 @@ class KINDLE(USBMS):
         if mc_path:
             timestamp = utcfromtimestamp(os.path.getmtime(mc_path))
             bookmarked_books['clippings'] = self.UserAnnotation(type='kindle_clippings',
-                                              value=dict(path=mc_path, timestamp=timestamp))
+                                              value={'path': mc_path, 'timestamp': timestamp})
 
         # This returns as job.result in gui2.ui.annotations_fetched(self,job)
         return bookmarked_books
@@ -264,12 +264,12 @@ class KINDLE(USBMS):
 
         # Add the last-read location
         if bookmark.book_format == 'pdf':
-            markup = _("%(time)s<br />Last page read: %(loc)d (%(pr)d%%)") % dict(
+            markup = _('%(time)s<br />Last page read: %(loc)d (%(pr)d%%)') % dict(
                     time=strftime('%x', timestamp.timetuple()),
                     loc=last_read_location,
                     pr=percent_read)
         else:
-            markup = _("%(time)s<br />Last page read: Location %(loc)d (%(pr)d%%)") % dict(
+            markup = _('%(time)s<br />Last page read: Location %(loc)d (%(pr)d%%)') % dict(
                     time=strftime('%x', timestamp.timetuple()),
                     loc=last_read_location,
                     pr=percent_read)
@@ -294,7 +294,7 @@ class KINDLE(USBMS):
                                 typ=user_notes[location]['type'],
                                 text=(user_notes[location]['text'] if
                                       user_notes[location]['type'] == 'Note' else
-                                      '<i>%s</i>' % user_notes[location]['text'])))
+                                      '<i>{}</i>'.format(user_notes[location]['text']))))
                 else:
                     if bookmark.book_format == 'pdf':
                         annotations.append(
@@ -312,7 +312,7 @@ class KINDLE(USBMS):
                 divTag.insert(dtc, annot)
                 dtc += 1
 
-        ka_soup.insert(0,divTag)
+        ka_soup.insert(0, divTag)
         return ka_soup
 
     def add_annotation_to_library(self, db, db_id, annotation):
@@ -351,7 +351,7 @@ class KINDLE(USBMS):
                                             bm.value.path, index_is_id=True)
         elif bm.type == 'kindle_clippings':
             # Find 'My Clippings' author=Kindle in database, or add
-            last_update = 'Last modified %s' % strftime('%x %X',bm.value['timestamp'].timetuple())
+            last_update = 'Last modified {}'.format(strftime('%x %X',bm.value['timestamp'].timetuple()))
             mc_id = list(db.data.search_getting_ids('title:"My Clippings"', '', sort_results=False))
             if mc_id:
                 db.add_format_with_hooks(mc_id[0], 'TXT', bm.value['path'],
@@ -610,7 +610,7 @@ class KINDLE2(KINDLE):
 
         # Create the sidecar folder if necessary
         if (self.sidecar_apnx):
-            path = os.path.join(os.path.dirname(filepath), filename+".sdr")
+            path = os.path.join(os.path.dirname(filepath), filename+'.sdr')
 
             if not os.path.exists(path):
                 os.makedirs(path)
@@ -623,7 +623,7 @@ class KINDLE2(KINDLE):
             except:
                 pass
 
-        apnx_path = '%s.apnx' % os.path.join(path, filename)
+        apnx_path = f'{os.path.join(path, filename)}.apnx'
         apnx_builder = APNXBuilder()
         # Check to see if there is an existing apnx file on Kindle we should keep.
         if opts.extra_customization[self.OPT_APNX_OVERWRITE] or not os.path.exists(apnx_path):
@@ -636,7 +636,7 @@ class KINDLE2(KINDLE):
                         if temp in self.EXTRA_CUSTOMIZATION_CHOICES[self.OPT_APNX_METHOD]:
                             method = temp
                         else:
-                            print("Invalid method choice for this book (%r), ignoring." % temp)
+                            print(f'Invalid method choice for this book ({temp!r}), ignoring.')
                     except:
                         print('Could not retrieve override method choice, using default.')
                 apnx_builder.write_apnx(filepath, apnx_path, method=method, page_count=custom_page_count)
