@@ -78,7 +78,6 @@ ARCHIVE_FMTS = ('zip', 'rar', 'oebzip')
 
 
 class Plumber:
-
     '''
     The `Plumber` manages the conversion pipeline. An UI should call the methods
     :method:`merge_ui_recommendations` and then :method:`run`. The plumber will
@@ -187,7 +186,7 @@ OptionRecommendation(name='disable_font_rescaling',
 OptionRecommendation(name='minimum_line_height',
             recommended_value=120.0, level=OptionRecommendation.LOW,
             help=_(
-            'The minimum line height, as a percentage of the element\'s '
+            "The minimum line height, as a percentage of the element's "
             'calculated font size. calibre will ensure that every element '
             'has a line height of at least this setting, irrespective of '
             'what the input document specifies. Set to zero to disable. '
@@ -560,13 +559,15 @@ OptionRecommendation(name='asciiize',
 OptionRecommendation(name='keep_ligatures',
             recommended_value=False, level=OptionRecommendation.LOW,
             help=_('Preserve ligatures present in the input document. '
-                'A ligature is a special rendering of a pair of '
+                'A ligature is a combined character of a pair of '
                 'characters like ff, fi, fl et cetera. '
                 'Most readers do not have support for '
                 'ligatures in their default fonts, so they are '
                 'unlikely to render correctly. By default, calibre '
                 'will turn a ligature into the corresponding pair of normal '
-                'characters. This option will preserve them instead.')
+                'characters. Note that ligatures here mean only unicode ligatures '
+                'not ligatures created via CSS or font styles. '
+                'This option will preserve them instead.')
         ),
 
 OptionRecommendation(name='title',
@@ -944,7 +945,7 @@ OptionRecommendation(name='search_replace',
 
         from calibre import browser
         from calibre.ptempfile import PersistentTemporaryFile
-        self.log('Downloading cover from %r'%url)
+        self.log(f'Downloading cover from {url!r}')
         br = browser()
         raw = br.open_novisit(url).read()
         buf = io.BytesIO(raw)
@@ -998,7 +999,7 @@ OptionRecommendation(name='search_replace',
                     setattr(self.opts, attr, x)
                     return
             self.log.warn(
-                'Profile (%s) %r is no longer available, using default'%(which, sval))
+                f'Profile ({which}) {sval!r} is no longer available, using default')
             for x in profiles():
                 if x.short_name == 'default':
                     setattr(self.opts, attr, x)
@@ -1016,7 +1017,7 @@ OptionRecommendation(name='search_replace',
             self.log('Conversion options changed from defaults:')
             for rec in self.changed_options:
                 if rec.option.name not in ('username', 'password'):
-                    self.log(' ', '%s:' % rec.option.name, repr(rec.recommended_value))
+                    self.log(' ', f'{rec.option.name}:', repr(rec.recommended_value))
         if self.opts.verbose > 1:
             self.log.debug('Resolved conversion options')
             try:
@@ -1071,7 +1072,7 @@ OptionRecommendation(name='search_replace',
         self.flush()
         if self.opts.embed_all_fonts or self.opts.embed_font_family:
             # Start the threaded font scanner now, for performance
-            from calibre.utils.fonts.scanner import font_scanner  # noqa
+            from calibre.utils.fonts.scanner import font_scanner  # noqa: F401
         import logging
 
         import css_parser
@@ -1203,7 +1204,7 @@ OptionRecommendation(name='search_replace',
             try:
                 fkey = list(map(float, fkey.split(',')))
             except Exception:
-                self.log.error('Invalid font size key: %r ignoring'%fkey)
+                self.log.error(f'Invalid font size key: {fkey!r} ignoring')
                 fkey = self.opts.dest.fkey
 
         from calibre.ebooks.oeb.transforms.jacket import Jacket
@@ -1297,7 +1298,7 @@ OptionRecommendation(name='search_replace',
             self.dump_oeb(self.oeb, out_dir)
             self.log('Processed HTML written to:', out_dir)
 
-        self.log.info('Creating %s...'%self.output_plugin.name)
+        self.log.info(f'Creating {self.output_plugin.name}...')
         our = CompositeProgressReporter(0.67, 1., self.ui_reporter)
         self.output_plugin.report_progress = our
         our(0., _('Running %s plugin')%self.output_plugin.name)
