@@ -4,20 +4,23 @@
 __license__ = 'GPL v3'
 __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import re, sys, copy, json
-from itertools import repeat
+import copy
+import json
+import re
+import sys
 from collections import defaultdict
+from itertools import repeat
 
 from lxml import etree
 from lxml.builder import ElementMaker
 
 from calibre import prints
-from calibre.ebooks.metadata import string_to_authors, check_isbn, check_doi
-from calibre.utils.xml_parse import safe_xml_fromstring
+from calibre.ebooks.metadata import check_doi, check_isbn, string_to_authors
 from calibre.ebooks.metadata.book.base import Metadata
 from calibre.ebooks.metadata.opf2 import dump_dict
-from calibre.utils.date import parse_date, isoformat, now
+from calibre.utils.date import isoformat, now, parse_date
 from calibre.utils.localization import canonicalize_lang, lang_as_iso639_1
+from calibre.utils.xml_parse import safe_xml_fromstring
 from polyglot.builtins import iteritems, string_or_bytes
 
 _xml_declaration = re.compile(r'<\?xml[^<>]+encoding\s*=\s*[\'"](.*?)[\'"][^<>]*>', re.IGNORECASE)
@@ -172,8 +175,8 @@ def read_series(root):
 
 
 def read_user_metadata(mi, root):
-    from calibre.utils.config import from_json
     from calibre.ebooks.metadata.book.json_codec import decode_is_multiple
+    from calibre.utils.config import from_json
     fields = set()
     for item in XPath('//calibre:custom_metadata')(root):
         for li in XPath('./rdf:Bag/rdf:li')(item):
@@ -437,13 +440,13 @@ def create_series(calibre, series, series_index):
     except (TypeError, ValueError):
         series_index = 1.0
     si = s.makeelement(expand('calibreSI:series_index'))
-    si.text = '%.2f' % series_index
+    si.text = f'{series_index:.2f}'
     s.append(si)
 
 
 def create_user_metadata(calibre, all_user_metadata):
+    from calibre.ebooks.metadata.book.json_codec import encode_is_multiple, object_to_unicode
     from calibre.utils.config import to_json
-    from calibre.ebooks.metadata.book.json_codec import object_to_unicode, encode_is_multiple
 
     s = calibre.makeelement(expand('calibre:custom_metadata'))
     calibre.append(s)
@@ -492,7 +495,7 @@ def metadata_to_xmp_packet(mi):
     if not mi.is_null('pubdate'):
         create_sequence_property(dc, 'dc:date', [isoformat(mi.pubdate, as_utc=False)])  # Adobe spec recommends local time
     if not mi.is_null('languages'):
-        langs = list(filter(None, map(lambda x:lang_as_iso639_1(x) or canonicalize_lang(x), mi.languages)))
+        langs = list(filter(None, (lang_as_iso639_1(x) or canonicalize_lang(x) for x in mi.languages)))
         if langs:
             create_sequence_property(dc, 'dc:language', langs, ordered=False)
 
@@ -511,7 +514,7 @@ def metadata_to_xmp_packet(mi):
         for scheme, val in iteritems(identifiers):
             if scheme in {'isbn', 'doi'}:
                 for prefix, parent in iteritems(extra_ids):
-                    ie = parent.makeelement(expand('%s:%s'%(prefix, scheme)))
+                    ie = parent.makeelement(expand(f'{prefix}:{scheme}'))
                     ie.text = val
                     parent.append(ie)
 
@@ -528,7 +531,7 @@ def metadata_to_xmp_packet(mi):
         except (TypeError, ValueError):
             pass
         else:
-            create_simple_property(calibre, 'calibre:rating', '%g' % r)
+            create_simple_property(calibre, 'calibre:rating', f'{r:g}')
     if not mi.is_null('series'):
         create_series(calibre, mi.series, mi.series_index)
     if not mi.is_null('timestamp'):
@@ -582,7 +585,7 @@ def find_nsmap(elems):
                 ans[pp] = ns
             else:
                 i += 1
-                ans['ns%d' % i] = ns
+                ans[f'ns{i}'] = ns
     return ans
 
 
@@ -615,7 +618,7 @@ def merge_xmp_packet(old, new):
     defined_tags |= {expand('xmp:' + x) for x in ('MetadataDate', 'Identifier')}
     # For redundancy also remove all fields explicitly set in the new packet
     defined_tags |= {x.tag for x in item_xpath(new)}
-    calibrens = '{%s}' % NS_MAP['calibre']
+    calibrens = '{{{}}}'.format(NS_MAP['calibre'])
     for elem in item_xpath(old):
         if elem.tag in defined_tags or (elem.tag and elem.tag.startswith(calibrens)):
             elem.getparent().remove(elem)
