@@ -13,27 +13,25 @@ import re
 import sys
 from collections import defaultdict
 from itertools import count
-from lxml import etree, html
 from operator import attrgetter
-from typing import Optional
+
+from lxml import etree, html
 
 from calibre import as_unicode, force_unicode, get_types_map, isbytestring
 from calibre.constants import __version__, filesystem_encoding
 from calibre.ebooks.chardet import xml_to_unicode
 from calibre.ebooks.conversion.preprocess import CSSPreProcessor
-from calibre.ebooks.oeb.parse_utils import (
-    XHTML, XHTML_NS, NotHTML, barename, namespace, parse_html,
-)
+from calibre.ebooks.oeb.parse_utils import XHTML, XHTML_NS, NotHTML, barename, namespace, parse_html
 from calibre.translations.dynamic import translate
 from calibre.utils.cleantext import clean_xml_chars
-from calibre.utils.icu import numeric_sort_key, title_case as icu_title
-from calibre.utils.localization import __
+from calibre.utils.icu import numeric_sort_key
+from calibre.utils.icu import title_case as icu_title
+from calibre.utils.localization import __, is_rtl_lang
 from calibre.utils.short_uuid import uuid4
 from calibre.utils.xml_parse import safe_xml_fromstring
 from polyglot.builtins import codepoint_to_chr, iteritems, itervalues, string_or_bytes
-from polyglot.urllib import (
-    unquote as urlunquote, urldefrag, urljoin, urlparse, urlunparse,
-)
+from polyglot.urllib import unquote as urlunquote
+from polyglot.urllib import urldefrag, urljoin, urlparse, urlunparse
 
 XML_NS       = 'http://www.w3.org/XML/1998/namespace'
 OEB_DOC_NS   = 'http://openebook.org/namespaces/oeb-document/1.0/'
@@ -304,7 +302,7 @@ def rewrite_links(root, link_repl_func, resolve_base_href=False):
         except UnicodeDecodeError:
             continue
 
-        if tag == XHTML('style') and el.text and \
+        if tag in (XHTML('style'), SVG('style')) and el.text and \
                 (_css_url_re.search(el.text) is not None or '@import' in
                         el.text):
             stylesheet = parser.parseString(el.text, validate=False)
@@ -342,7 +340,7 @@ SVG_MIME       = types_map['.svg']
 WEBP_MIME      = types_map['.webp']
 BINARY_MIME    = 'application/octet-stream'
 
-XHTML_CSS_NAMESPACE = '@namespace "%s";\n' % XHTML_NS
+XHTML_CSS_NAMESPACE = f'@namespace "{XHTML_NS}";\n'
 
 OEB_STYLES        = {CSS_MIME, OEB_CSS_MIME, 'text/x-oeb-css', 'xhtml/css'}
 OEB_DOCS          = {XHTML_MIME, 'text/html', OEB_DOC_MIME,
@@ -424,7 +422,7 @@ def xml2text(elem, pretty_print=False, method='text'):
 
 def escape_cdata(root):
     pat = re.compile(r'[<>&]')
-    for elem in root.iterdescendants('{%s}style' % XHTML_NS, '{%s}script' % XHTML_NS):
+    for elem in root.iterdescendants(f'{{{XHTML_NS}}}style', f'{{{XHTML_NS}}}script'):
         if elem.text and pat.search(elem.text) is not None:
             elem.text = etree.CDATA(elem.text.replace(']]>', r'\]\]\>'))
 
@@ -457,7 +455,8 @@ ASCII_CHARS   = frozenset(codepoint_to_chr(x) for x in range(128))
 UNIBYTE_CHARS = frozenset(x.encode('ascii') for x in ASCII_CHARS)
 USAFE         = ('ABCDEFGHIJKLMNOPQRSTUVWXYZ'
                  'abcdefghijklmnopqrstuvwxyz'
-                 '0123456789' '_.-/~')
+                 '0123456789'
+                 '_.-/~')
 URL_SAFE      = frozenset(USAFE)
 URL_SAFE_BYTES = frozenset(USAFE.encode('ascii'))
 URL_UNSAFE = [ASCII_CHARS - URL_SAFE, UNIBYTE_CHARS - URL_SAFE_BYTES]
@@ -465,13 +464,13 @@ del USAFE
 
 
 def urlquote(href):
-    """ Quote URL-unsafe characters, allowing IRI-safe characters.
+    ''' Quote URL-unsafe characters, allowing IRI-safe characters.
     That is, this function returns valid IRIs not valid URIs. In particular,
-    IRIs can contain non-ascii characters.  """
+    IRIs can contain non-ascii characters.  '''
     result = []
     isbytes = isinstance(href, bytes)
     unsafe = URL_UNSAFE[int(isbytes)]
-    esc, join = "%%%02x", ''
+    esc, join = '%%%02x', ''
     if isbytes:
         esc, join = esc.encode('ascii'), b''
     for char in href:
@@ -482,9 +481,9 @@ def urlquote(href):
 
 
 def urlnormalize(href):
-    """Convert a URL into normalized form, with all and only URL-unsafe
+    '''Convert a URL into normalized form, with all and only URL-unsafe
     characters URL quoted.
-    """
+    '''
     try:
         parts = urlparse(href)
     except ValueError as e:
@@ -499,11 +498,11 @@ def urlnormalize(href):
 
 
 def extract(elem):
-    """
+    '''
     Removes this element from the tree, including its children and
     text.  The tail text is joined to the previous element or
     parent.
-    """
+    '''
     parent = elem.getparent()
     if parent is not None:
         if elem.tail:
@@ -537,15 +536,15 @@ _css_logger.addHandler(_css_log_handler)
 
 
 class OEBError(Exception):
-    """Generic OEB-processing error."""
+    '''Generic OEB-processing error.'''
     pass
 
 
 class NullContainer:
-    """An empty container.
+    '''An empty container.
 
     For use with book formats which do not support container-like access.
-    """
+    '''
 
     def __init__(self, log):
         self.log = log
@@ -564,7 +563,7 @@ class NullContainer:
 
 
 class DirContainer:
-    """Filesystem directory container."""
+    '''Filesystem directory container.'''
 
     def __init__(self, path, log, ignore_opf=False):
         self.log = log
@@ -587,7 +586,7 @@ class DirContainer:
     def _unquote(self, path):
         # unquote must run on a bytestring and will return a bytestring
         # If it runs on a unicode object, it returns a double encoded unicode
-        # string: unquote(u'%C3%A4') != unquote(b'%C3%A4').decode('utf-8')
+        # string: unquote('%C3%A4') != unquote(b'%C3%A4').decode('utf-8')
         # and the latter is correct
         if isinstance(path, str):
             path = path.encode('utf-8')
@@ -621,7 +620,7 @@ class DirContainer:
             # On linux, if LANG is unset, the os.stat call tries to encode the
             # unicode path using ASCII
             # To replicate try:
-            # LANG=en_US.ASCII python -c "import os; os.stat(u'Espa\xf1a')"
+            # LANG=en_US.ASCII python -c "import os; os.stat('Espa\xf1a')"
             return os.path.isfile(path.encode(filesystem_encoding))
 
     def namelist(self):
@@ -644,13 +643,13 @@ class DirContainer:
 
 
 class Metadata:
-    """A collection of OEB data model metadata.
+    '''A collection of OEB data model metadata.
 
     Provides access to the list of items associated with a particular metadata
     term via the term's local name using either Python container or attribute
     syntax.  Return an empty list for any terms with no currently associated
     metadata items.
-    """
+    '''
 
     DC_TERMS      = {'contributor', 'coverage', 'creator', 'date',
                          'description', 'format', 'identifier', 'language',
@@ -666,7 +665,7 @@ class Metadata:
                      'xsi': XSI_NS, 'calibre': CALIBRE_NS}
 
     class Item:
-        """An item of OEB data model metadata.
+        '''An item of OEB data model metadata.
 
         The metadata term or name may be accessed via the :attr:`term` or
         :attr:`name` attributes.  The metadata value or content may be accessed
@@ -677,9 +676,9 @@ class Metadata:
         fully-qualified names using the Python container access syntax, or via
         their local names using Python attribute syntax.  Only attributes
         allowed by the OPF 2.0 specification are supported.
-        """
+        '''
         class Attribute:
-            """Smart accessor for allowed OEB metadata item attributes."""
+            '''Smart accessor for allowed OEB metadata item attributes.'''
 
             def __init__(self, attr, allowed=None):
                 if not callable(attr):
@@ -694,8 +693,7 @@ class Metadata:
                 allowed = self.allowed
                 if allowed is not None and term not in allowed:
                     raise AttributeError(
-                        'attribute {!r} not valid for metadata term {!r}'.format(
-                            self.attr(term), barename(obj.term)))
+                        f'attribute {self.attr(term)!r} not valid for metadata term {barename(obj.term)!r}')
                 return self.attr(term)
 
             def __get__(self, obj, cls):
@@ -773,8 +771,7 @@ class Metadata:
             return self.attrib.get(key, default)
 
         def __repr__(self):
-            return 'Item(term=%r, value=%r, attrib=%r)' \
-                % (barename(self.term), self.value, self.attrib)
+            return f'Item(term={barename(self.term)!r}, value={self.value!r}, attrib={self.attrib!r})'
 
         def __str__(self):
             return as_unicode(self.value)
@@ -817,7 +814,7 @@ class Metadata:
         self.primary_writing_mode = None
 
     def add(self, term, value, attrib={}, nsmap={}, **kwargs):
-        """Add a new metadata item."""
+        '''Add a new metadata item.'''
         item = self.Item(term, value, attrib, nsmap, **kwargs)
         items = self.items[barename(item.term)]
         items.append(item)
@@ -896,7 +893,7 @@ class Metadata:
 
 
 class Manifest:
-    """Collection of files composing an OEB data model book.
+    '''Collection of files composing an OEB data model book.
 
     Provides access to the content of the files composing the book and
     attributes associated with those files, including their internal paths,
@@ -909,10 +906,10 @@ class Manifest:
         the manifest items and the values are the items themselves.
     :attr:`hrefs`: A dictionary in which the keys are the internal paths of the
         manifest items and the values are the items themselves.
-    """
+    '''
 
     class Item:
-        """An OEB data model book content file.
+        '''An OEB data model book content file.
 
         Provides the following data members for accessing the file content and
         metadata associated with this particular file.
@@ -929,7 +926,7 @@ class Manifest:
             primary linear reading order and `False` for textual content items
             which are not (such as footnotes).  Meaningless for items which
             have a :attr:`spine_position` of `None`.
-        """
+        '''
 
         def __init__(self, oeb, id, href, media_type,
                      fallback=None, loader=str, data=None):
@@ -950,8 +947,7 @@ class Manifest:
             self._data = data
 
         def __repr__(self):
-            return 'Item(id=%r, href=%r, media_type=%r)' \
-                % (self.id, self.href, self.media_type)
+            return f'Item(id={self.id!r}, href={self.href!r}, media_type={self.media_type!r})'
 
         # Parsing {{{
         def _parse_xml(self, data):
@@ -1015,27 +1011,27 @@ class Manifest:
         def _fetch_css(self, path):
             hrefs = self.oeb.manifest.hrefs
             if path not in hrefs:
-                self.oeb.logger.warn('CSS import of missing file %r' % path)
-                return (None, None)
+                self.oeb.logger.warn(f'CSS import of missing file {path!r}')
+                return None, None
             item = hrefs[path]
             if item.media_type not in OEB_STYLES:
-                self.oeb.logger.warn('CSS import of non-CSS file %r' % path)
-                return (None, None)
+                self.oeb.logger.warn(f'CSS import of non-CSS file {path!r}')
+                return None, None
             data = item.data.cssText
             enc = None if isinstance(data, str) else 'utf-8'
-            return (enc, data)
+            return enc, data
 
         # }}}
 
         @property
-        def data_as_bytes_or_none(self) -> Optional[bytes]:
+        def data_as_bytes_or_none(self) -> bytes | None:
             if self._loader is None:
                 return None
             return self._loader(getattr(self, 'html_input_href', self.href))
 
         @property
         def data(self):
-            """Provides MIME type sensitive access to the manifest
+            '''Provides MIME type sensitive access to the manifest
             entry's associated content.
 
             - XHTML, HTML, and variant content is parsed as necessary to
@@ -1046,7 +1042,7 @@ class Manifest:
               CSS DOM stylesheet.
             - All other content is returned as a :class:`str` or :class:`bytes`
               object with no special parsing.
-            """
+            '''
             data = self._data
             if data is None:
                 data = self.data_as_bytes_or_none
@@ -1063,7 +1059,7 @@ class Manifest:
             elif mt in OEB_STYLES:
                 data = self._parse_css(data)
             elif mt == 'text/plain':
-                self.oeb.log.warn('%s contains data in TXT format'%self.href,
+                self.oeb.log.warn(f'{self.href} contains data in TXT format',
                         'converting to HTML')
                 data = self._parse_txt(data)
                 self.media_type = XHTML_MIME
@@ -1140,15 +1136,15 @@ class Manifest:
             return sp, (self.media_type or '').lower(), numeric_sort_key(href), self.id
 
         def relhref(self, href):
-            """Convert the URL provided in :param:`href` from a book-absolute
+            '''Convert the URL provided in :param:`href` from a book-absolute
             reference to a reference relative to this manifest item.
-            """
+            '''
             return rel_href(self.href, href)
 
         def abshref(self, href):
-            """Convert the URL provided in :param:`href` from a reference
+            '''Convert the URL provided in :param:`href` from a reference
             relative to this manifest item to a book-absolute reference.
-            """
+            '''
             try:
                 purl = urlparse(href)
             except ValueError:
@@ -1179,7 +1175,7 @@ class Manifest:
         self.hrefs = {}
 
     def add(self, id, href, media_type, fallback=None, loader=None, data=None):
-        """Add a new item to the book manifest.
+        '''Add a new item to the book manifest.
 
         The item's :param:`id`, :param:`href`, and :param:`media_type` are all
         required.  A :param:`fallback` item-id is required for any items with a
@@ -1187,7 +1183,7 @@ class Manifest:
         item's data itself may be provided with :param:`data`, or a loader
         function for the data may be provided with :param:`loader`, or the
         item's data may later be set manually via the :attr:`data` attribute.
-        """
+        '''
         item = self.Item(
             self.oeb, id, href, media_type, fallback, loader, data)
         self.items.add(item)
@@ -1196,7 +1192,7 @@ class Manifest:
         return item
 
     def remove(self, item):
-        """Removes :param:`item` from the manifest."""
+        '''Removes :param:`item` from the manifest.'''
         if item in self.ids:
             item = self.ids[item]
         del self.ids[item.id]
@@ -1213,14 +1209,14 @@ class Manifest:
         self.items.remove(item)
 
     def generate(self, id=None, href=None):
-        """Generate a new unique identifier and/or internal path for use in
+        '''Generate a new unique identifier and/or internal path for use in
         creating a new manifest item, using the provided :param:`id` and/or
         :param:`href` as bases.
 
         Returns an two-tuple of the new id and path.  If either :param:`id` or
         :param:`href` are `None` then the corresponding item in the return
         tuple will also be `None`.
-        """
+        '''
         if id is not None:
             base = id
             index = 1
@@ -1295,13 +1291,13 @@ class Manifest:
 
 
 class Spine:
-    """Collection of manifest items composing an OEB data model book's main
+    '''Collection of manifest items composing an OEB data model book's main
     textual content.
 
     The spine manages which manifest items compose the book's main textual
     content and the sequence in which they appear.  Provides Python container
     access as a list-like object.
-    """
+    '''
 
     def __init__(self, oeb):
         self.oeb = oeb
@@ -1318,14 +1314,14 @@ class Spine:
         return linear
 
     def add(self, item, linear=None):
-        """Append :param:`item` to the end of the `Spine`."""
+        '''Append :param:`item` to the end of the `Spine`.'''
         item.linear = self._linear(linear)
         item.spine_position = len(self.items)
         self.items.append(item)
         return item
 
     def insert(self, index, item, linear):
-        """Insert :param:`item` at position :param:`index` in the `Spine`."""
+        '''Insert :param:`item` at position :param:`index` in the `Spine`.'''
         item.linear = self._linear(linear)
         item.spine_position = index
         self.items.insert(index, item)
@@ -1334,7 +1330,7 @@ class Spine:
         return item
 
     def remove(self, item):
-        """Remove :param:`item` from the `Spine`."""
+        '''Remove :param:`item` from the `Spine`.'''
         index = item.spine_position
         self.items.pop(index)
         for i in range(index, len(self.items)):
@@ -1377,15 +1373,15 @@ class Spine:
 
 
 class Guide:
-    """Collection of references to standard frequently-occurring sections
+    '''Collection of references to standard frequently-occurring sections
     within an OEB data model book.
 
     Provides dictionary-like access, in which the keys are the OEB reference
     type identifiers and the values are `Reference` objects.
-    """
+    '''
 
     class Reference:
-        """Reference to a standard book section.
+        '''Reference to a standard book section.
 
         Provides the following instance data members:
 
@@ -1394,7 +1390,7 @@ class Guide:
         :attr:`title`: Human-readable section title.
         :attr:`href`: Book-internal URL of the referenced section.  May include
             a fragment identifier.
-        """
+        '''
         _TYPES_TITLES = [('cover', __('Cover')),
                          ('title-page', __('Title page')),
                          ('toc', __('Table of Contents')),
@@ -1430,12 +1426,11 @@ class Guide:
             self.href = urlnormalize(href)
 
         def __repr__(self):
-            return 'Reference(type=%r, title=%r, href=%r)' \
-                % (self.type, self.title, self.href)
+            return f'Reference(type={self.type!r}, title={self.title!r}, href={self.href!r})'
 
         @property
         def item(self):
-            """The manifest item associated with this reference."""
+            '''The manifest item associated with this reference.'''
             path = urldefrag(self.href)[0]
             hrefs = self.oeb.manifest.hrefs
             return hrefs.get(path, None)
@@ -1445,7 +1440,7 @@ class Guide:
         self.refs = {}
 
     def add(self, type, title, href):
-        """Add a new reference to the `Guide`."""
+        '''Add a new reference to the `Guide`.'''
         if href:
             href = str(href)
         ref = self.Reference(self.oeb, type, title, href)
@@ -1507,7 +1502,7 @@ class Guide:
 
 
 class TOC:
-    """Represents a hierarchical table of contents or navigation tree for
+    '''Represents a hierarchical table of contents or navigation tree for
     accessing arbitrary semantic sections within an OEB data model book.
 
     Acts as a node within the navigation tree.  Provides list-like access to
@@ -1520,7 +1515,7 @@ class TOC:
     :attr:`author`: Optional author attribution for periodicals <mbp:>
     :attr:`description`: Optional description attribute for periodicals <mbp:>
     :attr:`toc_thumbnail`: Optional toc thumbnail image
-    """
+    '''
 
     def __init__(self, title=None, href=None, klass=None, id=None,
             play_order=None, author=None, description=None, toc_thumbnail=None):
@@ -1538,7 +1533,7 @@ class TOC:
         self.toc_thumbnail = toc_thumbnail
 
     def add(self, title, href, klass=None, id=None, play_order=0, author=None, description=None, toc_thumbnail=None):
-        """Create and return a new sub-node of this node."""
+        '''Create and return a new sub-node of this node.'''
         node = TOC(title, href, klass, id, play_order, author, description, toc_thumbnail)
         self.nodes.append(node)
         return node
@@ -1554,7 +1549,7 @@ class TOC:
         return False
 
     def iter(self):
-        """Iterate over this node and all descendants in depth-first order."""
+        '''Iterate over this node and all descendants in depth-first order.'''
         yield self
         for child in self.nodes:
             yield from child.iter()
@@ -1580,7 +1575,7 @@ class TOC:
         return False
 
     def iterdescendants(self, breadth_first=False):
-        """Iterate over all descendant nodes in depth-first order."""
+        '''Iterate over all descendant nodes in depth-first order.'''
         if breadth_first:
             for child in self.nodes:
                 yield child
@@ -1591,16 +1586,16 @@ class TOC:
                 yield from child.iter()
 
     def __iter__(self):
-        """Iterate over all immediate child nodes."""
+        '''Iterate over all immediate child nodes.'''
         yield from self.nodes
 
     def __getitem__(self, index):
         return self.nodes[index]
 
     def autolayer(self):
-        """Make sequences of children pointing to the same content file into
+        '''Make sequences of children pointing to the same content file into
         children of the first node referencing that file.
-        """
+        '''
         prev = None
         for node in list(self.nodes):
             if prev and urldefrag(prev.href)[0] == urldefrag(node.href)[0]:
@@ -1610,14 +1605,14 @@ class TOC:
                 prev = node
 
     def depth(self):
-        """The maximum depth of the navigation tree rooted at this node."""
+        '''The maximum depth of the navigation tree rooted at this node.'''
         try:
             return max(node.depth() for node in self.nodes) + 1
         except ValueError:
             return 1
 
     def get_lines(self, lvl=0):
-        ans = [('\t'*lvl) + 'TOC: %s --> %s'%(self.title, self.href)]
+        ans = [('\t'*lvl) + f'TOC: {self.title} --> {self.href}']
         for child in self:
             ans.extend(child.get_lines(lvl+1))
         return ans
@@ -1686,14 +1681,14 @@ class TOC:
 
 
 class PageList:
-    """Collection of named "pages" to mapped positions within an OEB data model
+    '''Collection of named "pages" to mapped positions within an OEB data model
     book's textual content.
 
     Provides list-like access to the pages.
-    """
+    '''
 
     class Page:
-        """Represents a mapping between a page name and a position within
+        '''Represents a mapping between a page name and a position within
         the book content.
 
         Provides the following instance data attributes:
@@ -1707,7 +1702,7 @@ class PageList:
             fashion in print, such as the cover and title pages).
         :attr:`klass`: Optional semantic class of this page.
         :attr:`id`: Optional unique identifier for this page.
-        """
+        '''
         TYPES = {'front', 'normal', 'special'}
 
         def __init__(self, name, href, type='normal', klass=None, id=None):
@@ -1721,7 +1716,7 @@ class PageList:
         self.pages = []
 
     def add(self, name, href, type='normal', klass=None, id=None):
-        """Create a new page and add it to the `PageList`."""
+        '''Create a new page and add it to the `PageList`.'''
         page = self.Page(name, href, type, klass, id)
         self.pages.append(page)
         return page
@@ -1765,7 +1760,7 @@ class PageList:
 
 
 class OEBBook:
-    """Representation of a book in the IDPF OEB data model."""
+    '''Representation of a book in the IDPF OEB data model.'''
 
     COVER_SVG_XP    = XPath('h:body//svg:svg[position() = 1]')
     COVER_OBJECT_XP = XPath('h:body//h:object[@data][position() = 1]')
@@ -1775,7 +1770,7 @@ class OEBBook:
             css_preprocessor=CSSPreProcessor(),
             encoding='utf-8', pretty_print=False,
             input_encoding='utf-8'):
-        """Create empty book.  Arguments:
+        '''Create empty book.  Arguments:
 
         :param:`encoding`: Default encoding for textual content read
             from an external container.
@@ -1804,7 +1799,7 @@ class OEBBook:
         :attr:`toc`: Hierarchical table of contents.
         :attr:`pages`: List of "pages," such as indexed to a print edition of
             the same text.
-        """
+        '''
         _css_log_handler.log = logger
         self.encoding = encoding
         self.input_encoding = input_encoding
@@ -1824,6 +1819,15 @@ class OEBBook:
         self.auto_generated_toc = True
         self._temp_files = []
 
+    def set_page_progression_direction_if_needed(self):
+        if not self.spine.page_progression_direction:
+            try:
+                lang = self.metadata.language[0].value
+                if is_rtl_lang(lang):
+                    self.spine.page_progression_direction = 'rtl'
+            except Exception:
+                pass
+
     def clean_temp_files(self):
         for path in self._temp_files:
             try:
@@ -1833,19 +1837,19 @@ class OEBBook:
 
     @classmethod
     def generate(cls, opts):
-        """Generate an OEBBook instance from command-line options."""
+        '''Generate an OEBBook instance from command-line options.'''
         encoding = opts.encoding
         pretty_print = opts.pretty_print
         return cls(encoding=encoding, pretty_print=pretty_print)
 
     def translate(self, text):
-        """Translate :param:`text` into the book's primary language."""
+        '''Translate :param:`text` into the book's primary language.'''
         lang = str(self.metadata.language[0])
         lang = lang.split('-', 1)[0].lower()
         return translate(lang, text)
 
     def decode(self, data):
-        """Automatically decode :param:`data` into a `unicode` object."""
+        '''Automatically decode :param:`data` into a `unicode` object.'''
         def fix_data(d):
             return d.replace('\r\n', '\n').replace('\r', '\n')
         if isinstance(data, str):
@@ -1879,11 +1883,11 @@ class OEBBook:
         return fix_data(data)
 
     def to_opf1(self):
-        """Produce OPF 1.2 representing the book's metadata and structure.
+        '''Produce OPF 1.2 representing the book's metadata and structure.
 
         Returns a dictionary in which the keys are MIME types and the values
         are tuples of (default) filenames and lxml.etree element structures.
-        """
+        '''
         package = etree.Element('package',
             attrib={'unique-identifier': self.uid.id})
         self.metadata.to_opf1(package)
@@ -1923,7 +1927,6 @@ class OEBBook:
             href = urlnormalize(selector(elem)[0])
             order = playorder.get(href, i)
             elem.attrib['playOrder'] = str(order)
-        return
 
     def _to_ncx(self):
         try:
@@ -1959,11 +1962,11 @@ class OEBBook:
         return ncx
 
     def to_opf2(self, page_map=False):
-        """Produce OPF 2.0 representing the book's metadata and structure.
+        '''Produce OPF 2.0 representing the book's metadata and structure.
 
         Returns a dictionary in which the keys are MIME types and the values
         are tuples of (default) filenames and lxml.etree element structures.
-        """
+        '''
         results = {}
         package = etree.Element(OPF('package'),
             attrib={'version': '2.0', 'unique-identifier': self.uid.id},
@@ -1990,8 +1993,8 @@ class OEBBook:
 
 
 def rel_href(base_href, href):
-    """Convert the URL provided in :param:`href` to a URL relative to the URL
-    in :param:`base_href`  """
+    '''Convert the URL provided in :param:`href` to a URL relative to the URL
+    in :param:`base_href`  '''
     if urlparse(href).scheme:
         return href
     if '/' not in base_href:
