@@ -18,7 +18,7 @@ from calibre.ptempfile import better_mktemp
 
 from . import open_for_read, open_for_write
 
-"""
+'''
 States.
 1. 'not_in_table'
     1. 'cw<tb<row-def___' start a row definition
@@ -43,23 +43,23 @@ States.
 5. 'in_cell'
     1. 'mi<mk<not-in-tbl', end table
     2. 'cw<tb<cell______', end cell
-"""
+'''
 
 
 class Table:
-    """
+    '''
     Make tables.
     Logic:
     Read one line at a time. The default state (self.__state) is
     'not_in_table'. Look for either a 'cw<tb<in-table__', or a row definition.
-    """
+    '''
 
     def __init__(self,
             in_file,
             bug_handler,
             copy=None,
             run_level=1,):
-        """
+        '''
         Required:
             'file'--file to parse
         Optional:
@@ -68,7 +68,7 @@ class Table:
             directory from which the script is run.)
         Returns:
             nothing
-            """
+        '''
         self.__file = in_file
         self.__bug_handler = bug_handler
         self.__copy = copy
@@ -76,32 +76,32 @@ class Table:
         self.__write_to = better_mktemp()
 
     def __initiate_values(self):
-        """
+        '''
         Initiate all values.
-        """
+        '''
         self.__state_dict = {
-        'in_table':         self.__in_table_func,
-        'in_row_def':       self.__in_row_def_func,
-        'not_in_table':     self.__not_in_table_func,
-        'in_cell':          self.__in_cell_func,
-        'in_row':           self.__in_row_func,
+        'in_table'      : self.__in_table_func,
+        'in_row_def'    : self.__in_row_def_func,
+        'not_in_table'  : self.__not_in_table_func,
+        'in_cell'       : self.__in_cell_func,
+        'in_row'        : self.__in_row_func,
         }
         self.__not_in_table_dict = {
-        'cw<tb<row-def___':   self.__found_row_def_func,
-        'cw<tb<in-table__': self.__start_table_func,
+        'cw<tb<row-def___'  : self.__found_row_def_func,
+        'cw<tb<in-table__'  : self.__start_table_func,
         'mi<mk<in-table__'  : self.__start_table_func,
         }
         # can't use this dictionary. When in row_definition, many tokens
         # require multiple definitions
         self.__in_row_definition_dict = {
-        'mi<mk<not-in-tbl'  :   self.__end_row_table_func,
-        'mi<mk<pard-start'  :   self.__end_row_def_func,
+        'mi<mk<not-in-tbl'  : self.__end_row_table_func,
+        'mi<mk<pard-start'  : self.__end_row_def_func,
         }
         self.__in_row_dict = {
-        'mi<mk<not-in-tbl'  :   self.__close_table,
-        'mi<mk<pard-start'  :   self.__start_cell_func,
-        'cw<tb<row_______'  :   self.__end_row_func,
-        'cw<tb<cell______'  :   self.__empty_cell,
+        'mi<mk<not-in-tbl'  : self.__close_table,
+        'mi<mk<pard-start'  : self.__start_cell_func,
+        'cw<tb<row_______'  : self.__end_row_func,
+        'cw<tb<cell______'  : self.__empty_cell,
         }
         # set the default state
         self.__state = ['not_in_table']
@@ -113,14 +113,14 @@ class Table:
         self.__cell_widths = []
 
     def __in_table_func(self, line):
-        """
+        '''
         Requires:
             line -- line to parse
         Logic:
             Look for the end of the table. If found, close out the table.
             Look for  'mi<mk<pard-start', which marks the beginning of a row. Start
             a row and start a cell.
-        """
+        '''
         # 'cell'               : ('tb', 'cell______', self.default_func),
         if self.__token_info == 'mi<mk<not-in-tbl' or\
             self.__token_info == 'mi<mk<sect-start' or\
@@ -138,7 +138,7 @@ class Table:
         self.__write_obj.write(line)
 
     def __not_in_table_func(self, line):
-        """
+        '''
         Requires:
             line -- the line of text read in from document
         Returns:
@@ -148,14 +148,14 @@ class Table:
             mark the start of a table: 'cw<tb<row-def', or 'cw<tb<in-table__'.
             If these tokens are found, use another method to start a table
             and change states. Otherwise, just output the line.
-        """
+        '''
         action = self.__not_in_table_dict.get(self.__token_info)
         if action:
             action(line)
         self.__write_obj.write(line)
 
     def __close_table(self, line):
-        """
+        '''
         Requires:
             line -- line to parse
         Returns:
@@ -164,7 +164,7 @@ class Table:
             Write the end marker for the table.
             Write the end tag for the table.
             Set the state to ['not_in_table']
-        """
+        '''
         self.__write_obj.write('mi<mk<table-end_\n')
         self.__state = ['not_in_table']
         self.__table_data[-1]['number-of-columns'] = self.__max_number_cells_in_row
@@ -175,7 +175,7 @@ class Table:
         self.__table_data[-1]['average-cell-width'] = average_cell_width
 
     def __found_row_def_func(self, line):
-        """
+        '''
         Requires:
             line don't need this except for consistency with other methods.
         Returns:
@@ -183,7 +183,7 @@ class Table:
         Logic:
             A row definition has been found. Collect all the data from this
             to use later in writing attributes for the table.
-        """
+        '''
         self.__state.append('in_row_def')
         self.__last_cell_position = 0
         self.__row_dict = {}
@@ -192,7 +192,7 @@ class Table:
         self.__cell_widths = []
 
     def __start_table_func(self, line):
-        """
+        '''
         Requires:
             line -- line to parse
         Returns:
@@ -201,7 +201,7 @@ class Table:
             Add the 'in_table' to the state list.
             Write out the table marker.
             Initialize table values (not sure about these yet)
-        """
+        '''
         self.__rows_in_table = 0
         self.__cells_in_table = 0
         self.__cells_in_row = 0
@@ -212,18 +212,18 @@ class Table:
         self.__state.append('in_table')
 
     def __end_row_table_func(self, line):
-        """
+        '''
         Requires:
             line --just for consistencey
         Returns:
             ?
         Logic:
             ?
-        """
+        '''
         self.__close_table(self, line)
 
     def __end_row_def_func(self, line):
-        """
+        '''
         Requires:
             line --just for consistency
         Returns:
@@ -233,7 +233,7 @@ class Table:
             get rid of the last {} in the cell list
             figure out the number of cells based on the self.__row_dict[widths]
             ('122, 122')
-        """
+        '''
         if len(self.__state) > 0:
             if self.__state[-1] == 'in_row_def':
                 self.__state.pop()
@@ -246,7 +246,7 @@ class Table:
             self.__row_dict['number-of-cells'] = num_cells
 
     def __in_row_def_func(self, line):
-        """
+        '''
         Requires:
             line --line to parse
         Returns:
@@ -258,7 +258,7 @@ class Table:
             While in the row definition, certain tokens can end a row or end a table.
             If a paragrah definition (pard-start) is found, and the you are already in
             a table, start of a row.
-        """
+        '''
         if self.__token_info == 'cw<tb<row_______':
             # write tags
             self.__end_row_func(line)
@@ -289,7 +289,7 @@ class Table:
             self.__write_obj.write(line)
 
     def __handle_row_token(self, line):
-        """
+        '''
         Requires:
             line -- line to parse
         Returns:
@@ -304,7 +304,7 @@ class Table:
             the last item in the cell list. ([{border:something, width:something},
                     {border:something, width:something}])
     cw<bd<bor-t-r-to<nu<bdr-hair__|bdr-li-wid:0.50
-        """
+        '''
         if line[3:5] == 'bd':
             border_obj = border_parse.BorderParse()
             the_dict = border_obj.parse_border(line)
@@ -330,7 +330,7 @@ class Table:
             self.__row_dict['header'] = 'true'
 
     def __start_cell_func(self, line):
-        """
+        '''
         Required:
             line -- the line of text
         Returns:
@@ -341,7 +341,7 @@ class Table:
             Write value => attributes for key=> value
             pop the self.__cell_list.
             Otherwise, print out a cell tag.
-        """
+        '''
         self.__state.append('in_cell')
         # self.__cell_list = []
         if len(self.__cell_list) > 0:
@@ -361,7 +361,7 @@ class Table:
         self.__cells_in_row += 1
 
     def __start_row_func(self, line):
-        """
+        '''
         Required:
             line -- the line of text
         Returns:
@@ -369,7 +369,7 @@ class Table:
         Logic:
             Append 'in_row' for states
             Write value => attributes for key=> value
-        """
+        '''
         self.__state.append('in_row')
         self.__write_obj.write('mi<tg<open-att__<row')
         keys = self.__row_dict.keys()
@@ -380,7 +380,7 @@ class Table:
         self.__rows_in_table += 1
 
     def __found_cell_position(self, line):
-        """
+        '''
         needs:
             line: current line
         returns:
@@ -390,7 +390,7 @@ class Table:
            If the cell is the first cell, you should add the left cell position to it.
            (This value is often negative.)
             Next, set the new last_cell_position to the current cell position.
-        """
+        '''
         # cw<tb<cell-posit<nu<216.00
         new_cell_position = round(float(line[20:-1]), 2)
         left_position = 0
@@ -399,11 +399,11 @@ class Table:
             left_position = float(left_position)
         width = new_cell_position - self.__last_cell_position - left_position
         # width = round(width, 2)
-        width = '%.2f' % width
+        width = f'{width:.2f}'
         self.__last_cell_position = new_cell_position
         widths_exists = self.__row_dict.get('widths')
         if widths_exists:
-            self.__row_dict['widths'] += ', %s' % str(width)
+            self.__row_dict['widths'] += f', {width!s}'
         else:
             self.__row_dict['widths'] = str(width)
         self.__cell_list[-1]['width'] = width
@@ -411,7 +411,7 @@ class Table:
         self.__cell_widths.append(width)
 
     def __in_cell_func(self, line):
-        """
+        '''
         Required:
             line
         Returns:
@@ -423,7 +423,7 @@ class Table:
             Look for the close of the cell. If found, use the close cell function to close out
             the cell.
             Otherwise, print out the line.
-        """
+        '''
         # cw<tb<cell______<nu<true
         # mi<mk<sect-start
         if self.__token_info == 'mi<mk<not-in-tbl' or\
@@ -434,20 +434,20 @@ class Table:
             self.__end_row_func(line)
             self.__close_table(line)
             self.__write_obj.write(line)
-        elif self.__token_info ==  'cw<tb<cell______':
+        elif self.__token_info == 'cw<tb<cell______':
             self.__end_cell_func(line)
         else:
             self.__write_obj.write(line)
 
     def __end_cell_func(self, line):
-        """
+        '''
         Requires:
             line
         Returns:
             nothing
         Logic:
             End the cell. Print out the closing marks. Pop the self.__state.
-        """
+        '''
         if len(self.__state) > 1:
             if self.__state[-1] == 'in_cell':
                 self.__state.pop()
@@ -468,20 +468,18 @@ class Table:
             if action:
                 action(line)
             self.__write_obj.write(line)
-        """
-        elif self.__token_info == 'mi<mk<pard-start':
-            self.__start_cell_func(line)
-            self.__write_obj.write(line)
-        elif self.__token_info == 'cw<tb<row_______':
-            self.__end_row_func(line)
-            self.__write_obj.write(line)
-        else:
-            self.__write_obj.write(line)
-        """
+        # elif self.__token_info == 'mi<mk<pard-start':
+        #     self.__start_cell_func(line)
+        #     self.__write_obj.write(line)
+        # elif self.__token_info == 'cw<tb<row_______':
+        #     self.__end_row_func(line)
+        #     self.__write_obj.write(line)
+        # else:
+        #     self.__write_obj.write(line)
 
     def __end_row_func(self, line):
-        """
-        """
+        '''
+        '''
         if len(self.__state) > 1 and self.__state[-1] == 'in_row':
             self.__state.pop()
             self.__write_obj.write('mi<tg<close_____<row\n')
@@ -493,7 +491,7 @@ class Table:
         self.__list_of_cells_in_row.append(self.__cells_in_row)
 
     def __empty_cell(self, line):
-        """
+        '''
         Required:
             line -- line of text
         Returns:
@@ -501,7 +499,7 @@ class Table:
         Logic:
             Write an empty tag with attributes if there are attributes.
             Otherwise, written an empty tag with cell as element.
-        """
+        '''
         if len(self.__cell_list) > 0:
             self.__write_obj.write('mi<tg<empty-att_<cell')
             cell_dict = self.__cell_list[-1]
@@ -515,7 +513,7 @@ class Table:
         self.__cells_in_row += 1
 
     def __mode(self, the_list):
-        """
+        '''
         Required:
             the_list -- a list of something
         Returns:
@@ -523,7 +521,7 @@ class Table:
         Logic:
             get the count of each item in list. The count that is the greatest
             is the mode.
-        """
+        '''
         max = 0
         mode = 'not-defined'
         for item in the_list:
@@ -534,7 +532,7 @@ class Table:
         return mode
 
     def make_table(self):
-        """
+        '''
         Requires:
             nothing
         Returns:
@@ -542,7 +540,7 @@ class Table:
         Logic:
             Read one line in at a time. Determine what action to take based on
             the state.
-        """
+        '''
         self.__initiate_values()
         read_obj = open_for_read(self.__file)
         self.__write_obj = open_for_write(self.__write_to)
@@ -552,7 +550,7 @@ class Table:
             line = line_to_read
             self.__token_info = line[:16]
             action = self.__state_dict.get(self.__state[-1])
-            # print self.__state[-1]
+            # print(self.__state[-1])
             if action is None:
                 sys.stderr.write('No matching state in module table.py\n')
                 sys.stderr.write(self.__state[-1] + '\n')
@@ -561,7 +559,7 @@ class Table:
         self.__write_obj.close()
         copy_obj = copy.Copy(bug_handler=self.__bug_handler)
         if self.__copy:
-            copy_obj.copy_file(self.__write_to, "table.data")
+            copy_obj.copy_file(self.__write_to, 'table.data')
         copy_obj.rename(self.__write_to, self.__file)
         os.remove(self.__write_to)
         return self.__table_data
