@@ -134,7 +134,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         except Exception:
             pass
 
-        self.notes_utilities = NotesUtilities(self.table, "authors",
+        self.notes_utilities = NotesUtilities(self.table, 'authors',
                   lambda item: int(self.table.item(item.row(), AUTHOR_COLUMN).data(Qt.ItemDataRole.UserRole)))
 
         self.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setText(_('&OK'))
@@ -317,7 +317,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
             self.notes_utilities.set_icon(note_item, id_, id_ in all_items_that_have_notes)
             row += 1
 
-        headers = { # this depends on the dict being ordered, which is true from python 3.7
+        headers = {  # this depends on the dict being ordered, which is true from python 3.7
             _('Author'): _('Name of the author'),
             _('Author sort'): _('Value used to sort this author'),
             _('Count'): _('Count of books with this author'),
@@ -346,7 +346,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         select_item = None
         if id_to_select:
             use_as = tweaks['categories_use_field_for_author_name'] == 'author_sort'
-            for row in range(0, len(auts_to_show)):
+            for row in range(len(auts_to_show)):
                 if is_first_letter:
                     item_txt = str(self.table.item(row, AUTHOR_SORT_COLUMN).text() if use_as
                                                 else self.table.item(row, AUTHOR_COLUMN).text())
@@ -382,7 +382,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
     def save_state(self):
         self.table_column_widths = []
-        for c in range(0, self.table.columnCount()):
+        for c in range(self.table.columnCount()):
             self.table_column_widths.append(self.table.columnWidth(c))
         gprefs['general_category_editor_row_height'] = self.table.verticalHeader().sectionSize(0)
         gprefs['manage_authors_table_widths'] = self.table_column_widths
@@ -390,7 +390,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
     def table_column_resized(self, col, old, new):
         self.table_column_widths = []
-        for c in range(0, self.table.columnCount()):
+        for c in range(self.table.columnCount()):
             self.table_column_widths.append(self.table.columnWidth(c))
 
     def resizeEvent(self, *args):
@@ -404,7 +404,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
             # widths will be remembered
             w = self.table.width() - 25 - self.table.verticalHeader().width()
             w //= self.table.columnCount()
-            for c in range(0, self.table.columnCount()):
+            for c in range(self.table.columnCount()):
                 self.table.setColumnWidth(c, w)
         self.save_state()
 
@@ -462,7 +462,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
                     ca = m.addAction(_('Copy to author sort'))
                     ca.triggered.connect(self.copy_au_to_aus)
                     m.addSeparator()
-                    ca = m.addAction(QIcon.cached_icon('lt.png'), _("Show books by author in book list"))
+                    ca = m.addAction(QIcon.cached_icon('lt.png'), _('Show books by author in book list'))
                     ca.triggered.connect(self.search_in_book_list)
                 else:
                     ca = m.addAction(_('Copy to author'))
@@ -482,8 +482,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
     def search_in_book_list(self):
         from calibre.gui2.ui import get_gui
         row = self.context_item.row()
-        get_gui().search.set_search_string('authors:="%s"' %
-                           str(self.table.item(row, AUTHOR_COLUMN).text()).replace(r'"', r'\"'))
+        get_gui().search.set_search_string('authors:="{}"'.format(str(self.table.item(row, AUTHOR_COLUMN).text()).replace(r'"', r'\"')))
 
     def copy_to_clipboard(self):
         cb = QApplication.clipboard()
@@ -543,7 +542,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
         st = icu_lower(str(self.find_box.currentText()))
         if not st:
             return
-        for _ in range(0, self.table.rowCount()*2):
+        for _ in range(self.table.rowCount()*2):
             self.start_find_pos = (self.start_find_pos + 1) % (self.table.rowCount()*2)
             r = (self.start_find_pos//2) % self.table.rowCount()
             c = self.start_find_pos % 2
@@ -600,7 +599,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
     def do_recalc_author_sort(self):
         with self.no_cell_changed():
-            for row in range(0,self.table.rowCount()):
+            for row in range(self.table.rowCount()):
                 item_aut = self.table.item(row, AUTHOR_COLUMN)
                 id_ = int(item_aut.data(Qt.ItemDataRole.UserRole))
                 aut  = str(item_aut.text()).strip()
@@ -620,7 +619,7 @@ class EditAuthorsDialog(QDialog, Ui_EditAuthorsDialog):
 
     def do_auth_sort_to_author(self):
         with self.no_cell_changed():
-            for row in range(0,self.table.rowCount()):
+            for row in range(self.table.rowCount()):
                 aus  = str(self.table.item(row, AUTHOR_SORT_COLUMN).text()).strip()
                 item_aut = self.table.item(row, AUTHOR_COLUMN)
                 id_ = int(item_aut.data(Qt.ItemDataRole.UserRole))
