@@ -83,7 +83,7 @@ class MatchBooks(QDialog, Ui_MatchBooks):
         self.books_table.setHorizontalHeaderItem(0, t)
         t = QTableWidgetItem(_('Authors'))
         self.books_table.setHorizontalHeaderItem(1, t)
-        t = QTableWidgetItem(ngettext("Series", 'Series', 1))
+        t = QTableWidgetItem(ngettext('Series', 'Series', 1))
         self.books_table.setHorizontalHeaderItem(2, t)
         self.books_table_header_height = self.books_table.height()
         self.books_table.cellDoubleClicked.connect(self.book_doubleclicked)
@@ -168,8 +168,8 @@ class MatchBooks(QDialog, Ui_MatchBooks):
             # have a width. Assume 25. Not a problem because user-changed column
             # widths will be remembered
             w = self.books_table.width() - 25 - self.books_table.verticalHeader().width()
-            w /= self.books_table.columnCount()
-            for c in range(0, self.books_table.columnCount()):
+            w //= self.books_table.columnCount()
+            for c in range(self.books_table.columnCount()):
                 self.books_table.setColumnWidth(c, w)
         self.save_state()
 
@@ -184,7 +184,7 @@ class MatchBooks(QDialog, Ui_MatchBooks):
 
     def save_state(self):
         self.books_table_column_widths = []
-        for c in range(0, self.books_table.columnCount()):
+        for c in range(self.books_table.columnCount()):
             self.books_table_column_widths.append(self.books_table.columnWidth(c))
         gprefs['match_books_dialog_books_table_widths'] = self.books_table_column_widths
         self.save_geometry(gprefs, 'match_books_dialog_geometry')
