@@ -59,7 +59,7 @@ def render_pin(color=None, save_to=None):
 
 
 def group_numbers(numbers):
-    for k, g in groupby(enumerate(sorted(numbers)), lambda i_x:i_x[0] - i_x[1]):
+    for k, g in groupby(enumerate(sorted(numbers)), lambda i_x: i_x[0] - i_x[1]):
         first = None
         for last in g:
             if first is None:
@@ -97,7 +97,7 @@ class ColumnColor:  # {{{
 
 
 def themed_icon_name(icon_dir, icon_name):
-    root,ext = os.path.splitext(icon_name)
+    root, ext = os.path.splitext(icon_name)
     # Remove any theme from the icon name
     root = root.removesuffix('-for-dark-theme').removesuffix('-for-light-theme')
     # Check if the correct themed icon exists.
@@ -204,16 +204,16 @@ class BooksModel(QAbstractTableModel):  # {{{
         self.bi_font.setItalic(True)
         self.styled_columns = {}
         self.orig_headers = {
-                        'title'     : _("Title"),
-                        'ondevice'   : _("On Device"),
-                        'authors'   : _("Author(s)"),
-                        'size'      : _("Size (MB)"),
-                        'timestamp' : _("Date"),
+                        'title'     : _('Title'),
+                        'ondevice'  : _('On Device'),
+                        'authors'   : _('Author(s)'),
+                        'size'      : _('Size (MB)'),
+                        'timestamp' : _('Date'),
                         'pubdate'   : _('Published'),
                         'rating'    : _('Rating'),
-                        'publisher' : _("Publisher"),
-                        'tags'      : _("Tags"),
-                        'series'    : ngettext("Series", 'Series', 1),
+                        'publisher' : _('Publisher'),
+                        'tags'      : _('Tags'),
+                        'series'    : ngettext('Series', 'Series', 1),
                         'last_modified' : _('Modified'),
                         'languages' : _('Languages'),
                         'formats'   : _('Formats'),
@@ -888,7 +888,7 @@ class BooksModel(QAbstractTableModel):  # {{{
                     val = fffunc(field_obj, idfunc(idx), default_value=0) or 0
                     if val == 0:
                         return None
-                    ans = '%.1f' % (val * sz_mult)
+                    ans = f'{val*sz_mult:.1f}'
                     return ('<0.1' if ans == '0.0' else ans)
             elif field == 'languages':
                 def func(idx):
@@ -1127,8 +1127,8 @@ class BooksModel(QAbstractTableModel):  # {{{
             cname = self.column_map[index.column()]
             return self.styled_columns.get(cname)
         # elif role == Qt.ItemDataRole.ToolTipRole and index.isValid():
-        #    if self.column_map[index.column()] in self.editable_cols:
-        #        return (_("Double click to <b>edit</b> me<br><br>"))
+        #     if self.column_map[index.column()] in self.editable_cols:
+        #         return (_("Double click to <b>edit</b> me<br><br>"))
         return None
 
     def headerData(self, section, orientation, role):
@@ -1366,7 +1366,7 @@ class OnDeviceSearch(SearchQueryParser):  # {{{
         self.model = model
 
     def universal_set(self):
-        return set(range(0, len(self.model.db)))
+        return set(range(len(self.model.db)))
 
     def get_matches(self, location, query):
         location = location.lower().strip()
@@ -1392,13 +1392,13 @@ class OnDeviceSearch(SearchQueryParser):  # {{{
         all_locs = set(self.USABLE_LOCATIONS) - {'all', 'tags', 'search'}
         locations = all_locs if location == 'all' else [location]
         q = {
-             'title' : lambda x : getattr(x, 'title').lower(),
-             'author': lambda x: ' & '.join(getattr(x, 'authors')).lower(),
-             'collections':lambda x: ','.join(getattr(x, 'device_collections')).lower(),
-             'format':lambda x: os.path.splitext(x.path)[1].lower(),
-             'inlibrary':lambda x : getattr(x, 'in_library'),
-             'tags':lambda x : getattr(x, 'tags', [])
-             }
+            'title': lambda x: getattr(x, 'title').lower(),
+            'author': lambda x: ' & '.join(getattr(x, 'authors')).lower(),
+            'collections':lambda x: ','.join(getattr(x, 'device_collections')).lower(),
+            'format':lambda x: os.path.splitext(x.path)[1].lower(),
+            'inlibrary':lambda x: getattr(x, 'in_library'),
+            'tags':lambda x: getattr(x, 'tags', [])
+        }
         for x in ('author', 'format'):
             q[x+'s'] = q[x]
         upf = prefs['use_primary_find_in_search']
@@ -1533,7 +1533,7 @@ class DeviceBooksModel(BooksModel):  # {{{
         self.count_changed()
 
     def paths_deleted(self, paths):
-        self.map = list(range(0, len(self.db)))
+        self.map = list(range(len(self.db)))
         self.resort(False)
         self.research(True)
         self.count_changed()
@@ -1627,8 +1627,8 @@ class DeviceBooksModel(BooksModel):  # {{{
 
         keygen = {
                 'title': ('title_sorter', lambda x: sort_key(x) if x else b''),
-                'authors' : author_key,
-                'size' : ('size', int),
+                'authors': author_key,
+                'size': ('size', int),
                 'timestamp': ('datetime', functools.partial(dt_factory, assume_utc=True)),
                 'collections': ('device_collections', lambda x:sorted(x,
                     key=sort_key)),
@@ -1669,7 +1669,7 @@ class DeviceBooksModel(BooksModel):  # {{{
     def set_database(self, db):
         self.custom_columns = {}
         self.db = db
-        self.map = list(range(0, len(db)))
+        self.map = list(range(len(db)))
         self.research(reset=False)
         self.resort()
         self.count_changed()
@@ -1840,7 +1840,7 @@ class DeviceBooksModel(BooksModel):  # {{{
                     cname == 'collections' and (
                         callable(getattr(self.db, 'supports_collections', None)) and self.db.supports_collections())
             ):
-                return (_("Double click to <b>edit</b> me<br><br>"))
+                return (_('Double click to <b>edit</b> me<br><br>'))
         elif role == Qt.ItemDataRole.DecorationRole and cname == 'inlibrary':
             if hasattr(self.db[self.map[row]], 'in_library_waiting'):
                 return (self.sync_icon)
@@ -1893,7 +1893,7 @@ class DeviceBooksModel(BooksModel):  # {{{
                 self.upload_collections.emit(self.db)
                 return True
 
-            if cname == 'title' :
+            if cname == 'title':
                 self.db[idx].title = val
             elif cname == 'authors':
                 self.db[idx].authors = string_to_authors(val)
