@@ -50,6 +50,13 @@ from calibre.utils.titlecase import titlecase
 from polyglot.builtins import as_unicode
 
 
+def adjust_for_non_bmp_chars(raw: str, start: int, end: int) -> tuple[int, int]:
+    adjusted_start = utf16_length(raw[:start])
+    end = adjusted_start + utf16_length(raw[start:end])
+    start = adjusted_start
+    return start, end
+
+
 def get_highlighter(syntax):
     if syntax:
         try:
@@ -275,7 +282,7 @@ class TextEdit(PlainTextEdit):
         self.setFont(font)
         self.highlighter.apply_theme(theme)
         fm = self.fontMetrics()
-        self.number_width = max(map(lambda x:fm.horizontalAdvance(str(x)), range(10)))
+        self.number_width = max(fm.horizontalAdvance(str(x)) for x in range(10))
         self.size_hint = QSize(self.expected_geometry[0] * fm.averageCharWidth(), self.expected_geometry[1] * fm.height())
         self.highlight_color = theme_color(theme, 'HighlightRegion', 'bg')
         self.highlight_cursor_line()
@@ -395,6 +402,7 @@ class TextEdit(PlainTextEdit):
         start, end = m.span()
         if start == end:
             return False
+        start, end = adjust_for_non_bmp_chars(raw, start, end)
         if wrap:
             if reverse:
                 textpos = c.anchor()
@@ -486,7 +494,7 @@ class TextEdit(PlainTextEdit):
         start, end = m.span()
         if start == end:
             return False
-        end = start + utf16_length(raw[start:end])
+        start, end = adjust_for_non_bmp_chars(raw, start, end)
         if wrap and not complete:
             if reverse:
                 textpos = c.anchor()
@@ -532,7 +540,7 @@ class TextEdit(PlainTextEdit):
             start, end = m.span()
             if start == end:
                 return False
-            end = start + utf16_length(raw[start:end])
+            start, end = adjust_for_non_bmp_chars(raw, start, end)
         if reverse:
             start, end = end, start
         c.clearSelection()
@@ -622,7 +630,7 @@ class TextEdit(PlainTextEdit):
             c.movePosition(QTextCursor.MoveOperation.Start)
             self.setTextCursor(c)
             return True
-        base = r'''%%s\s*=\s*['"]{0,1}%s''' % regex.escape(anchor)
+        base = rf'''%s\s*=\s*['"]{{0,1}}{regex.escape(anchor)}'''
         raw = str(self.toPlainText())
         m = regex.search(base % 'id', raw)
         if m is None:
@@ -900,9 +908,9 @@ class TextEdit(PlainTextEdit):
                 return
             r, g, b, a = color.getRgb()
             if a == 255:
-                color = 'rgb(%d, %d, %d)' % (r, g, b)
+                color = f'rgb({r}, {g}, {b})'
             else:
-                color = 'rgba(%d, %d, %d, %.2g)' % (r, g, b, a/255)
+                color = f'rgba({r}, {g}, {b}, {a / 255:.2g})'
         prefix, suffix = {
             'bold': ('<b>', '</b>'),
             'italic': ('<i>', '</i>'),
@@ -910,8 +918,8 @@ class TextEdit(PlainTextEdit):
             'strikethrough': ('<span style="text-decoration: line-through">', '</span>'),
             'superscript': ('<sup>', '</sup>'),
             'subscript': ('<sub>', '</sub>'),
-            'color': ('<span style="color: %s">' % color, '</span>'),
-            'background-color': ('<span style="background-color: %s">' % color, '</span>'),
+            'color': (f'<span style="color: {color}">', '</span>'),
+            'background-color': (f'<span style="background-color: {color}">', '</span>'),
         }[formatting]
         self.smarts.surround_with_custom_tag(self, prefix, suffix)
 
@@ -929,7 +937,7 @@ class TextEdit(PlainTextEdit):
             c.setPosition(right, QTextCursor.MoveMode.KeepAnchor)
             href = prepare_string_for_xml(href, True)
             if fullpage:
-                template =  '''\
+                template = '''\
 <div style="page-break-before:always; page-break-after:always; page-break-inside:avoid">\
 <svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" \
 version="1.1" width="100%%" height="100%%" viewBox="0 0 {w} {h}" preserveAspectRatio="{a}">\
