@@ -356,7 +356,7 @@ class Highlights(QTreeWidget):
                 for key in keys:
                     section = smap[key]
                     if section['tfam']:
-                        section['title'] = ' ➤ '.join(tfam)
+                        section['title'] = ' ➤ '.join(section['tfam'])
                     elif section['tsec'] and section['lsec']:
                         section['title'] = ' ➤ '.join((section['tsec'], section['lsec']))
 
@@ -441,7 +441,7 @@ class Highlights(QTreeWidget):
         else:
             if cr < 0:
                 cr = -1
-            indices = chain(range(cr + 1, count), range(0, cr + 1))
+            indices = chain(range(cr + 1, count), range(cr + 1))
         for i in indices:
             h = items[i].data(0, highlight_role)
             if pat.search(h['highlighted_text']) is not None or pat.search(h.get('notes') or '') is not None:
