@@ -21,6 +21,7 @@ class QCoreTextFontEngine;
 #include <qpa/qplatformwindow.h>
 #include <qpa/qplatformfontdatabase.h>
 #include <qpa/qplatformtheme.h>
+#include <qpa/qplatformnativeinterface.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -122,6 +123,13 @@ QAbstractEventDispatcher *HeadlessIntegration::createEventDispatcher() const
 #endif
 }
 
+QPlatformNativeInterface *HeadlessIntegration::nativeInterface() const
+{
+    if (!m_nativeInterface)
+        m_nativeInterface.reset(new QPlatformNativeInterface);
+    return m_nativeInterface.get();
+}
+
 HeadlessIntegration *HeadlessIntegration::instance()
 {
     return static_cast<HeadlessIntegration *>(QGuiApplicationPrivate::platformIntegration());
