@@ -8,11 +8,13 @@ __docformat__ = 'restructuredtext en'
 import hashlib
 from collections import OrderedDict, namedtuple
 from functools import partial
+
 from html5_parser import parse
 from lxml import etree
 from lxml.builder import ElementMaker
 
-from calibre import force_unicode, guess_type, prepare_string_for_xml as xml
+from calibre import force_unicode, guess_type
+from calibre import prepare_string_for_xml as xml
 from calibre.constants import __appname__
 from calibre.db.view import sanitize_sort_field_name
 from calibre.ebooks.metadata import authors_to_string, fmt_sidx, rating_to_stars
@@ -57,9 +59,9 @@ def format_tag_string(tags, sep, joinval=', '):
 DC_NS = 'http://purl.org/dc/terms/'
 E = ElementMaker(namespace='http://www.w3.org/2005/Atom',
                  nsmap={
-                     None   : 'http://www.w3.org/2005/Atom',
-                     'dc'   : DC_NS,
-                     'opds' : 'http://opds-spec.org/2010/catalog',
+                     None  : 'http://www.w3.org/2005/Atom',
+                     'dc'  : DC_NS,
+                     'opds': 'http://opds-spec.org/2010/catalog',
                      })
 
 
@@ -116,10 +118,10 @@ PREVIOUS_LINK  = partial(NAVLINK, rel='previous')
 
 
 def html_to_lxml(raw):
-    raw = '<div>%s</div>'%raw
+    raw = f'<div>{raw}</div>'
     root = parse(raw, keep_doctype=False, namespace_elements=False, maybe_xhtml=False, sanitize_names=True)
     root = next(root.iterdescendants('div'))
-    root.set('xmlns', "http://www.w3.org/1999/xhtml")
+    root.set('xmlns', 'http://www.w3.org/1999/xhtml')
     raw = etree.tostring(root, encoding='unicode')
     try:
         return safe_xml_fromstring(raw, recover=False)
@@ -157,7 +159,7 @@ def CATALOG_ENTRY(item, item_kind, request_context, updated, catalog_name,
     else:
         name = item.name
     return E.entry(
-            TITLE(name + ('' if not add_kind else ' (%s)'%item_kind)),
+            TITLE(name + ('' if not add_kind else f' ({item_kind})')),
             ID(id_),
             UPDATED(updated),
             E.content(count, type='text'),
@@ -197,15 +199,14 @@ def ACQUISITION_ENTRY(book_id, updated, request_context):
             fm = field_metadata[key]
             datatype = fm['datatype']
             if datatype == 'text' and fm['is_multiple']:
-                extra.append('%s: %s<br />'%
-                             (xml(name),
+                extra.append('{}: {}<br />'.format(xml(name),
                               xml(format_tag_string(val,
                                     fm['is_multiple']['ui_to_list'],
                                     joinval=fm['is_multiple']['list_to_ui']))))
             elif datatype == 'comments' or (fm['datatype'] == 'composite' and fm['display'].get('contains_html', False)):
-                extra.append('%s: %s<br />'%(xml(name), comments_to_html(str(val))))
+                extra.append(f'{xml(name)}: {comments_to_html(str(val))}<br />')
             else:
-                extra.append('%s: %s<br />'%(xml(name), xml(str(val))))
+                extra.append(f'{xml(name)}: {xml(str(val))}<br />')
     if mi.comments:
         comments = comments_to_html(mi.comments)
         extra.append(comments)
@@ -214,7 +215,7 @@ def ACQUISITION_ENTRY(book_id, updated, request_context):
     ans = E.entry(TITLE(mi.title), E.author(E.name(authors_to_string(mi.authors))), ID('urn:uuid:' + mi.uuid), UPDATED(mi.last_modified),
                   E.published(mi.timestamp.isoformat()))
     if mi.pubdate and not is_date_undefined(mi.pubdate):
-        ans.append(ans.makeelement('{%s}date' % DC_NS))
+        ans.append(ans.makeelement(f'{{{DC_NS}}}date'))
         ans[-1].text = mi.pubdate.isoformat()
     if len(extra):
         ans.append(E.content(extra, type='xhtml'))
@@ -225,22 +226,22 @@ def ACQUISITION_ENTRY(book_id, updated, request_context):
             fmt = fmt.lower()
             mt = guess_type('a.'+fmt)[0]
             if mt:
-                link = E.link(type=mt, href=get(what=fmt), rel="http://opds-spec.org/acquisition")
+                link = E.link(type=mt, href=get(what=fmt), rel='http://opds-spec.org/acquisition')
                 ffm = fm.get(fmt.upper())
                 if ffm:
                     link.set('length', str(ffm['size']))
                     link.set('mtime', ffm['mtime'].isoformat())
                 ans.append(link)
-    ans.append(E.link(type='image/jpeg', href=get(what='cover'), rel="http://opds-spec.org/cover"))
-    ans.append(E.link(type='image/jpeg', href=get(what='thumb'), rel="http://opds-spec.org/thumbnail"))
-    ans.append(E.link(type='image/jpeg', href=get(what='cover'), rel="http://opds-spec.org/image"))
-    ans.append(E.link(type='image/jpeg', href=get(what='thumb'), rel="http://opds-spec.org/image/thumbnail"))
+    ans.append(E.link(type='image/jpeg', href=get(what='cover'), rel='http://opds-spec.org/cover'))
+    ans.append(E.link(type='image/jpeg', href=get(what='thumb'), rel='http://opds-spec.org/thumbnail'))
+    ans.append(E.link(type='image/jpeg', href=get(what='cover'), rel='http://opds-spec.org/image'))
+    ans.append(E.link(type='image/jpeg', href=get(what='thumb'), rel='http://opds-spec.org/image/thumbnail'))
 
     return ans
 
-
 # }}}
 
+
 default_feed_title = __appname__ + ' ' + _('Library')
 
 
@@ -312,13 +313,13 @@ class NavFeed(Feed):
     def __init__(self, id_, updated, request_context, offsets, page_url, up_url, title=None):
         kwargs = {'up_link': up_url}
         kwargs['first_link'] = page_url
-        kwargs['last_link']  = page_url+'&offset=%d'%offsets.last_offset
+        kwargs['last_link']  = page_url+f'&offset={offsets.last_offset}'
         if offsets.offset > 0:
             kwargs['previous_link'] = \
-                page_url+'&offset=%d'%offsets.previous_offset
+                page_url+f'&offset={offsets.previous_offset}'
         if offsets.next_offset > -1:
             kwargs['next_link'] = \
-                page_url+'&offset=%d'%offsets.next_offset
+                page_url+f'&offset={offsets.next_offset}'
         if title:
             kwargs['title'] = title
         Feed.__init__(self, id_, updated, request_context, **kwargs)
@@ -422,7 +423,7 @@ def get_all_books(rc, which, page_url, up_url, offset=0):
 def get_navcatalog(request_context, which, page_url, up_url, offset=0):
     categories = request_context.get_categories()
     if which not in categories:
-        raise HTTPNotFound('Category %r not found'%which)
+        raise HTTPNotFound(f'Category {which!r} not found')
 
     items = categories[which]
     updated = request_context.last_modified()
@@ -549,17 +550,17 @@ def opds_category(ctx, rd, category, which):
         except Exception:
             # Might be a composite column, where we have the lookup key
             if not (category in rc.db.field_metadata and rc.db.field_metadata[category]['datatype'] == 'composite'):
-                raise HTTPNotFound('Tag %r not found'%which)
+                raise HTTPNotFound(f'Tag {which!r} not found')
 
     categories = rc.get_categories()
     if category not in categories:
-        raise HTTPNotFound('Category %r not found'%which)
+        raise HTTPNotFound(f'Category {which!r} not found')
 
     if category == 'search':
         try:
-            ids = rc.search('search:"%s"'%which)
+            ids = rc.search(f'search:"{which}"')
         except Exception:
-            raise HTTPNotFound('Search: %r not understood'%which)
+            raise HTTPNotFound(f'Search: {which!r} not understood')
         return get_acquisition_feed(rc, ids, offset, page_url, up_url, 'calibre-search:'+which)
 
     if type_ != 'I':
@@ -590,7 +591,7 @@ def opds_categorygroup(ctx, rd, category, which):
 
     category = from_hex_unicode(category)
     if category not in categories:
-        raise HTTPNotFound('Category %r not found'%which)
+        raise HTTPNotFound(f'Category {which!r} not found')
     category_meta = rc.db.field_metadata
     meta = category_meta.get(category, {})
     category_name = meta.get('name', which)
@@ -604,7 +605,7 @@ def opds_categorygroup(ctx, rd, category, which):
         return getattr(x, 'sort', x.name).lower().startswith(which.lower())
     items = [x for x in items if belongs(x, which)]
     if not items:
-        raise HTTPNotFound('No items in group %r:%r'%(category, which))
+        raise HTTPNotFound(f'No items in group {category!r}:{which!r}')
     updated = rc.last_modified()
 
     id_ = 'calibre-category-group-feed:'+category+':'+which
@@ -634,6 +635,6 @@ def opds_search(ctx, rd, query):
     try:
         ids = rc.search(query)
     except Exception:
-        raise HTTPNotFound('Search: %r not understood'%query)
+        raise HTTPNotFound(f'Search: {query!r} not understood')
     page_url = rc.url_for('/opds/search', query=query)
     return get_acquisition_feed(rc, ids, offset, page_url, rc.url_for('/opds'), 'calibre-search:'+query)
