@@ -32,8 +32,8 @@ COMPILER_PATH = 'rapydscript/compiler.js.xz'
 def abspath(x):
     return os.path.realpath(os.path.abspath(x))
 
-# Update RapydScript {{{
 
+# Update RapydScript {{{
 
 def update_rapydscript():
     import lzma
@@ -49,8 +49,8 @@ def update_rapydscript():
         f.write(raw)
 # }}}
 
-# Compiler {{{
 
+# Compiler {{{
 
 def to_dict(obj):
     return dict(zip(list(obj.keys()), list(obj.values())))
@@ -394,7 +394,7 @@ def run_rapydscript_tests():
             if fail_code is None:
                 fail_code = QWebEngineUrlRequestJob.Error.UrlNotFound
             rq.fail(fail_code)
-            print(f"Blocking FAKE_PROTOCOL request: {rq.requestUrl().toString()}", file=sys.stderr)
+            print(f'Blocking FAKE_PROTOCOL request: {rq.requestUrl().toString()}', file=sys.stderr)
 
     class Tester(QWebEnginePage):
 
@@ -468,8 +468,7 @@ def compile_viewer():
     icons = g['merge']()
     with open(os.path.join(base, 'resources', 'content-server', 'reset.css'), 'rb') as f:
         reset = f.read().decode('utf-8')
-    html = '<!DOCTYPE html>\n<html><head><style>{reset}</style></head><body>{icons}</body></html>'.format(
-            icons=icons, reset=reset)
+    html = f'<!DOCTYPE html>\n<html><head><style>{reset}</style></head><body>{icons}</body></html>'
 
     rapydscript_dir = os.path.join(base, 'src', 'pyj')
     fname = os.path.join(rapydscript_dir, 'viewer-main.pyj')
@@ -508,8 +507,8 @@ def compile_srv():
 
 # }}}
 
-# Translations {{{
 
+# Translations {{{
 
 def create_pot(source_files):
     c = compiler()
