@@ -48,7 +48,7 @@ class TestResult(unittest.TextTestResult):
         elapsed -= self.start_time.get(test, elapsed)
         self.times[test] = elapsed
         self.stream.writeln = orig
-        self.stream.writeln(' [%.1f s]' % elapsed)
+        self.stream.writeln(f' [{elapsed:.1f} s]')
 
     def stopTestRun(self):
         super().stopTestRun()
@@ -56,7 +56,7 @@ class TestResult(unittest.TextTestResult):
             tests = sorted(self.times, key=self.times.get, reverse=True)
             slowest = [f'{t.id()} [{self.times[t]:.1f} s]' for t in tests[:3]]
             if len(slowest) > 1:
-                self.stream.writeln('\nSlowest tests: %s' % ' '.join(slowest))
+                self.stream.writeln('\nSlowest tests: {}'.format(' '.join(slowest)))
 
 
 def find_tests_in_package(package, excludes=('main.py',)):
@@ -65,7 +65,7 @@ def find_tests_in_package(package, excludes=('main.py',)):
     excludes = set(excludes) | {x + 'c' for x in excludes}
     seen = set()
     for x in items:
-        if (x.endswith('.py') or x.endswith('.pyc')) and x not in excludes:
+        if (x.endswith(('.py', '.pyc'))) and x not in excludes:
             q = x.rpartition('.')[0]
             if q in seen:
                 continue
@@ -84,7 +84,7 @@ def itertests(suite):
                 stack.append(test)
                 continue
             if test.__class__.__name__ == 'ModuleImportFailure':
-                raise Exception('Failed to import a test module: %s' % test)
+                raise Exception(f'Failed to import a test module: {test}')
             yield test
 
 
@@ -146,7 +146,7 @@ def run_tests(find_tests, verbosity=4):
         else:
             tests = filter_tests_by_module(tests, args.name)
         if not tests._tests:
-            raise SystemExit('No test named %s found' % args.name)
+            raise SystemExit(f'No test named {args.name} found')
     run_cli(tests, verbosity, buffer=not args.name)
 
 
@@ -324,7 +324,7 @@ def run_test(test_name, verbosity=4, buffer=False):
     # calibre-debug -t test_name
     which_tests = None
     if test_name.startswith('@'):
-        which_tests = test_name[1:],
+        which_tests = (test_name[1:],)
     tests = find_tests(which_tests)
     if test_name != 'all':
         if test_name.startswith('.'):
